##  Integration Use Case: Cloud Migration
With most global enterprises adopting a cloud-first strategy, EAs and cloud architects (CAs) have been tasked with managing this widespread transformation and its financial impact on the business. This is especially true when determining which applications, for which business processes, would be best suited by a cloud migration to save costs and improve technical fit. What was once a manual effort of data entry and importing can now be accomplished seamlessly with the dynamic integration of Apptio and SAP LeanIX.
The Apptio-SAP LeanIX integration enables higher levels of collaboration across business and IT stakeholders evaluating cloud transformation strategies. This is accomplished through:
  * Streamlining feasibility analysis to determine which applications are viable candidates to be moved to the cloud
  * Structuring the cloud migration plan by looking at application data from multiple angles i.e. technical fit, functional fit, cost, and workload
  * Tracking the status of cloud transformation projects and associated costs
